@@ -80,7 +80,7 @@ class RuntimeContext(object):
         self.request_id = request_id
         if not isinstance(params, dict):
             params = json.loads(params)
-        self.params = params
+        self.params._data = params
 
     def __repr__(self):
         return f'<Context: request_id {self.request_id}>'
