@@ -68,7 +68,7 @@ def create_app(working_dir='.', log_file=''):
                 try:
                     logging.debug(f'event: {data.context.args}')
                     function = load(data, working_dir)
-                    ret = await function.call_func(data.context.args, data.context.params)
+                    ret = await function.call_func(data.id, data.context.args, data.context.params)
                     logging.debug(f'response: {ret}')
                     out_data = {key: value for key, value in ret.items() if re.match(r"out\d+", key)}
                     resp = FunctionResponse(id=data.id, success=True, data=out_data)
@@ -110,7 +110,7 @@ def load(data: FunctionParams, default_dir):
     node_function = module_imported.get(node_id)
     if not node_function:
         logging.info(f'node {node_id} import function {function} from {filename}')
-        node_function = loader.NodeFunction(working_dir, filename, function)
+        node_function = loader.NodeFunction(node_id, working_dir, filename, function)
         module_imported[node_id] = node_function
 
     return node_function
